@@ -1,8 +1,8 @@
 package HTML::Template::Compiled::Compiler::Classic;
-# $Id: Classic.pm 1047 2008-06-13 19:38:05Z tinita $
+# $Id: Classic.pm 1121 2011-08-28 17:03:20Z tinita $
 use strict;
 use warnings;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use base 'HTML::Template::Compiled::Compiler';
 
@@ -31,13 +31,13 @@ sub parse_var {
         my $lc = $loop_context{ lc $args{var} };
         return $lc;
     }
+    my $var = $t->get_case_sensitive ? $args{var} : uc $args{var};
     if ($t->get_global_vars & 1) {
         my $varstr =
-            "\$t->_get_var_global_sub(" . '$P,$$C,0,'."[undef,'$args{var}'])";
+            "\$t->_get_var_global_sub(" . '$P,$$C,0,'."[undef,'$var'])";
         return $varstr;
     }
     else {
-        my $var = $args{var};
         $var =~ s/\\/\\\\/g;
         $var =~ s/'/\\'/g;
         my $varstr = '$$C->{' . "'$var'" . '}';
